@@ -4,7 +4,6 @@
 # objective:
 # script start;
 
-# 1) on attach
 .onAttach <- function(
     libname,
     pkgname,
@@ -17,36 +16,28 @@
     xts_check_TZ = FALSE
   )
 
-  # 1) package
-  # header
-  rlang::inform(
-    header(
-      pkgname = pkgname,
-      pkgversion = utils::packageVersion(
-        pkgname
-      )
+
+  cli::cli_inform(
+    message = pkg_header(
+      pkgname
     ),
     ...,
     class = "packageStartupMessage"
   )
 
-  # 2) package information
-  # to the user
-  rlang::inform(
-    pkg_information(),
+  cli::cli_inform(
+    message = pkg_information(),
     ...,
     class = "packageStartupMessage"
   )
 
+
 }
 
-
-# 1) on detach
 .onDetach <- function(
     libpath,
     ...) {
 
-
   # 1) reset options
   # for xts suppressing
   # timezone messages
@@ -55,4 +46,5 @@
   )
 
 }
+
 # script end;
