@@ -2,6 +2,12 @@ testthat::test_that(
   desc = "Test that the convinience functions calibrates the data correctly",
   code = {
 
+    testthat::expect_false(
+      setequal(
+        zoo::index(FGIndex),
+        zoo::index(BTC)
+      )
+    )
 
     # 2) to align the indices,
     # we use the convincience functions
